==> ixnetwork_restpy-1.0.65.tar.gz: ixnetwork_restpy-1.0.65/uhd_restpy/testplatform/sessions/ixnetwork/topology/level_2d6a41b0a919905f176ad907ea4fdab6.py <==
# MIT LICENSE
#
# Copyright 1997 - 2020 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE. 
from uhd_restpy.base import Base
from uhd_restpy.files import Files


class Level(Base):
    """Fat Tree Topology - Per Level Info
    The Level class encapsulates a list of level resources that are managed by the system.
    A list of resources can be retrieved from the server using the Level.find() method.
    """

    __slots__ = ()
    _SDM_NAME = 'level'
    _SDM_ATT_MAP = {
        'NodeCount': 'nodeCount',
    }

    def __init__(self, parent):
        super(Level, self).__init__(parent)

    @property
    def NodeCount(self):
        """
        Returns
        -------
        - number: Number of Nodes Per Level
        """
        return self._get_attribute(self._SDM_ATT_MAP['NodeCount'])
    @NodeCount.setter
    def NodeCount(self, value):
        self._set_attribute(self._SDM_ATT_MAP['NodeCount'], value)

    def update(self, NodeCount=None):
        """Updates level resource on the server.

        Args
        ----
        - NodeCount (number): Number of Nodes Per Level

        Raises
        ------
        - ServerError: The server has encountered an uncategorized error condition
        """
        return self._update(self._map_locals(self._SDM_ATT_MAP, locals()))

    def find(self, NodeCount=None):
        """Finds and retrieves level resources from the server.

        All named parameters are evaluated on the server using regex. The named parameters can be used to selectively retrieve level resources from the server.
        To retrieve an exact match ensure the parameter value starts with ^ and ends with $
        By default the find method takes no parameters and will retrieve all level resources from the server.

        Args
        ----
        - NodeCount (number): Number of Nodes Per Level

        Returns
        -------
        - self: This instance with matching level resources retrieved from the server available through an iterator or index

        Raises
        ------
        - ServerError: The server has encountered an uncategorized error condition
        """
        return self._select(self._map_locals(self._SDM_ATT_MAP, locals()))

    def read(self, href):
        """Retrieves a single instance of level data from the server.

        Args
        ----
        - href (str): An href to the instance to be retrieved

        Returns
        -------
        - self: This instance with the level resources from the server available through an iterator or index

        Raises
        ------
        - NotFoundError: The requested resource does not exist on the server
        - ServerError: The server has encountered an uncategorized error condition
        """
        return self._read(href)

==> ixnetwork_restpy-1.1.2.tar.gz: ixnetwork_restpy-1.1.2/uhd_restpy/testplatform/sessions/ixnetwork/topology/level_2d6a41b0a919905f176ad907ea4fdab6.py <==
# MIT LICENSE
#
# Copyright 1997 - 2020 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE. 
from uhd_restpy.base import Base
from uhd_restpy.files import Files
from typing import List, Any, Union


class Level(Base):
    """Fat Tree Topology - Per Level Info
    The Level class encapsulates a list of level resources that are managed by the system.
    A list of resources can be retrieved from the server using the Level.find() method.
    """

    __slots__ = ()
    _SDM_NAME = 'level'
    _SDM_ATT_MAP = {
        'NodeCount': 'nodeCount',
    }
    _SDM_ENUM_MAP = {
    }

    def __init__(self, parent, list_op=False):
        super(Level, self).__init__(parent, list_op)

    @property
    def NodeCount(self):
        # type: () -> int
        """
        Returns
        -------
        - number: Number of Nodes Per Level
        """
        return self._get_attribute(self._SDM_ATT_MAP['NodeCount'])
    @NodeCount.setter
    def NodeCount(self, value):
        # type: (int) -> None
        self._set_attribute(self._SDM_ATT_MAP['NodeCount'], value)

    def update(self, NodeCount=None):
        # type: (int) -> Level
        """Updates level resource on the server.

        Args
        ----
        - NodeCount (number): Number of Nodes Per Level

        Raises
        ------
        - ServerError: The server has encountered an uncategorized error condition
        """
        return self._update(self._map_locals(self._SDM_ATT_MAP, locals()))

    def add(self, NodeCount=None):
        # type: (int) -> Level
        """Adds a new level resource on the json, only valid with config assistant

        Args
        ----
        - NodeCount (number): Number of Nodes Per Level

        Returns
        -------
        - self: This instance with all currently retrieved level resources using find and the newly added level resources available through an iterator or index

        Raises
        ------
        - Exception: if this function is not being used with config assistance
        """
        return self._add_xpath(self._map_locals(self._SDM_ATT_MAP, locals()))

    def find(self, NodeCount=None):
        # type: (int) -> Level
        """Finds and retrieves level resources from the server.

        All named parameters are evaluated on the server using regex. The named parameters can be used to selectively retrieve level resources from the server.
        To retrieve an exact match ensure the parameter value starts with ^ and ends with $
        By default the find method takes no parameters and will retrieve all level resources from the server.

        Args
        ----
        - NodeCount (number): Number of Nodes Per Level

        Returns
        -------
        - self: This instance with matching level resources retrieved from the server available through an iterator or index

        Raises
        ------
        - ServerError: The server has encountered an uncategorized error condition
        """
        return self._select(self._map_locals(self._SDM_ATT_MAP, locals()))

    def read(self, href):
        """Retrieves a single instance of level data from the server.

        Args
        ----
        - href (str): An href to the instance to be retrieved

        Returns
        -------
        - self: This instance with the level resources from the server available through an iterator or index

        Raises
        ------
        - NotFoundError: The requested resource does not exist on the server
        - ServerError: The server has encountered an uncategorized error condition
        """
        return self._read(href)
